.TH GMT l "1 Mar 2002"
.SH NAME
gmt \- The Generic Mapping Tools data processing and display software package
.SH INTRODUCTION
\fBGMT\fP is a collection of public-domain Unix tools that allows you to manipulate x,y
and x,y,z data sets (filtering, trend fitting, gridding, projecting, etc.)
and produce \fIPostScript\fP illustrations ranging from simple x-y plots, via
contour maps, to artificially illuminated surfaces and 3-d perspective
views in black/white or 24bit color. Linear, log10, and power scaling is supported in
additon to 25 common map projections. The processing and display routines within GMT
are completely general and will handle any (x,y) or (x,y,z) data as input.
.SH SYNOPSIS
\fBGMT\fP is also a wrapper script that can start any of the programs:
.br
.sp
\fBGMT\fP module module-options
.br
.sp
where module is the name of a GMT program and the options are those that pertain to
that particular program.
.SH GMT OVERVIEW
        The following is a summary of all the programs supplied with GMT and
a very short description of their purpose. Detailed information about each program can
be found in the separate manual pages.
.br
.sp
        blockmean L2 (x,y,z) data filter/decimator
.br
        blockmedian L1 (x,y,z) data filter/decimator
.br
        blockmode Mode (x,y,z) data filter/decimator
.br
        filter1d Filter 1-D data sets (time series)
.br
        fitcircle Finds the best-fitting great circle to a set of points
.br
        gmtconvert Convert between ASCII and binary 1-D tables
.br
        gmtdefaults List the current default settings
.br
        gmtmath Mathematical operations on data tables
.br
        gmtset Set individual default parameters
.br
        gmtselect Extract data subsets based on spatial criteria
.br
        grdfilter Filter 2-D data sets in the space domain
.br
        grd2cpt Make a color palette table from a grdfile
.br
        grd2xyz Conversion from 2-D gridded file to table data
.br
        grdclip Limit the z-range in gridded data
.br
        grdcontour Contouring of 2-D gridded data
.br
        grdcut Cut a sub-region from a grd file
.br
        grdedit Modify header information in a 2-D gridded file
.br
        grdfft Operate on grdfiles in the frequency domain
.br
        grdgradient Compute directional gradient from grdfiles
.br
        grdhisteq Histogram equalization for grdfiles
.br
        grdimage Produce images from 2-D gridded data
.br
        grdinfo Get information about grd files
.br
        grdlandmask Create mask grdfile from shoreline data base
.br
        grdmask Reset nodes outside a clip path to a constant
.br
        grdmath Mathematical operations on grdfiles
.br
        grdpaste Paste together grdfiles along a common edge
.br
        grdproject Project gridded data onto a new coordinate system
.br
        grdreformat Converting between different grdfile formats
.br
        grdsample Resample a 2-D gridded data set onto a new grid
.br
        grdtrend Fits polynomial trends to grdfiles
.br
        grdtrack Sampling of 2-D data set along 1-D track
.br
        grdvector Plot vector fields from grdfiles
.br
        grdview 3-D perspective imaging of 2-D gridded data
.br
        grdvolume Volume calculations from 2-D gridded data
.br
        makecpt Make GMT color palette tables
.br
        mapproject Forward or inverse map projections of table data
.br
        minmax Find extreme values in data tables
.br
        nearneighbor Nearest-neighbor gridding scheme
.br
        project Project data onto lines/great circles
.br
        psbasemap Create a basemap plot
.br
        psclip Use polygon files to define clipping paths
.br
        pscoast Plot coastlines and filled continents on maps
.br
        pscontour Contour xyz-data by triangulation
.br
        pshistogram Plot a histogram
.br
        psimage Plot images (Sun rasterfiles) on maps
.br
        psmask Create overlay to mask out regions on maps
.br
        psrose Plot sector or rose diagrams
.br
        psscale Plot grayscale or colorscale on maps
.br
        pstext Plot textstrings on maps
.br
        pswiggle Draw time-series along track on maps
.br
        psxy Plot symbols, polygons, and lines on maps
.br
        psxyz Plot symbols, polygons, and lines in 3-D
.br
        sample1d Resampling of 1-D table data sets
.br
        spectrum1d Compute various spectral estimates from time-series
.br
        splitxyz Split xyz-files into several segments
.br
        surface A continuous curvature gridding algorithm
.br
        trend1d Fits polynomial or Fourier trends to y = f(x) data
.br
        trend2d Fits polynomial trends to z = f(x,y) data
.br
        triangulate Perform optimal Delaunay triangulation and gridding
.br
        xyz2grd Convert equidistant xyz data to a 2-D grd file
.br
.SH "SEE ALSO"
Look up the individual man pages for details. By default, these pages are
in $GMTHOME/man/manl, depending on your installation settings.
Information is also available on the GMT home page gmt.soest.hawaii.edu
or locally under $GMTHOME/www/gmt/gmt_services.html
.SH REFERENCES
Wessel, P., and W. H. F. Smith, 2001, The Generic Mapping Tools (GMT) version
3.4 Technical Reference & Cookbook, SOEST/NOAA.
.br
Wessel, P., and W. H. F. Smith, 1998, New, Improved Version of Generic Mapping
Tools Released, EOS Trans., AGU, 79 (47), p. 579.
.br
Wessel, P., and W. H. F. Smith, 1995, New Version of the Generic Mapping Tools
Released, EOS Trans., AGU, 76 (33), p. 329.
.br
Wessel, P., and W. H. F. Smith, 1995, New Version of the Generic Mapping Tools
Released, http:
American Geophysical Union.
.br
Wessel, P., and W. H. F. Smith, 1991, Free Software Helps Map and Display Data,
EOS Trans., AGU, 72 (41), p. 441.
.br
